from pathlib import Path

DOSSIER_CONFIG_PYPODO="pypodo"
TODO_RC_FILE = "config"
REGEX_INDEX = "^\\d+$"
REGEX_SPACE_OR_ENDLINE = "( |$)"